'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

suite('End to End', function () {
  var assert = require('assert');
  var documenter = require('../');
  var debug = require('debug')('test');
  var _ = require('lodash');
  var tar = require('tar-stream');
  var rootdir = require('app-root-dir');
  var zlib = require('zlib');
  var validator = require('taskcluster-lib-validate');
  var base = require('taskcluster-base');

  var validate = null;
  var api = null;
  var exchanges = null;
  var references = null;
  var cfg = base.config();
  var credentials = cfg.taskcluster.credentials;
  var tier = 'core';

  suiteSetup((0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return validator({
              folder: './test/schemas',
              baseUrl: 'http://localhost:1203/',
              constants: { 'my-constant': 42 }
            });

          case 2:
            validate = _context.sent;

            api = new base.API({
              title: 'Testing Stuff',
              description: 'This is for testing stuff!'
            });
            exchanges = new base.Exchanges({
              title: 'Testing Stuff Again',
              description: 'Another test!'
            });
            references = [{ name: 'api', reference: api.reference({ baseUrl: 'http://localhost' }) }, { name: 'events', reference: exchanges.reference({ baseUrl: 'http://localhost' }) }];

          case 6:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));

  function assertInTarball(shoulds, tarball, done) {
    shoulds.push('taskcluster-lib-docs/metadata.json');
    shoulds.push('taskcluster-lib-docs/README.md');
    var contains = [];
    var extractor = tar.extract();
    extractor.on('entry', function (header, stream, callback) {
      stream.on('end', function () {
        contains.push(header.name);
        callback(); // ready for next entry
      });

      stream.resume(); // just auto drain the stream
    });

    extractor.on('finish', function () {
      done(assert.deepEqual(contains.sort(), shoulds.sort()));
    });

    tarball.pipe(zlib.Unzip()).pipe(extractor);
  }

  test('tarball exists', (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
    var doc;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return documenter({
              schemas: validate.schemas,
              tier: tier
            });

          case 2:
            doc = _context2.sent;

            assert.ok(doc.tgz);

          case 4:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  })));

  test('tarball is empty but exists', function () {
    var doc = documenter({
      tier: tier
    });
    assert.equal(doc.tgz, null);
  });

  test('test publish tarball', (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
    var doc;
    return _regenerator2.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return documenter({
              project: 'testing',
              schemas: validate.schemas,
              tier: tier,
              credentials: credentials,
              docsFolder: './test/docs/',
              references: references,
              publish: true
            });

          case 2:
            doc = _context3.sent;

            assert.ok(doc.tgz);

          case 4:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  })));

  test('tarball contains docs and metadata', function () {
    var _ref4 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee4(done) {
      var doc, shoulds;
      return _regenerator2.default.wrap(function _callee4$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              _context4.next = 2;
              return documenter({
                docsFolder: './test/docs',
                tier: tier
              });

            case 2:
              doc = _context4.sent;
              shoulds = ['taskcluster-lib-docs/docs/example.md'];

              assertInTarball(shoulds, doc.tgz, done);

            case 5:
            case 'end':
              return _context4.stop();
          }
        }
      }, _callee4, this);
    }));

    return function (_x) {
      return _ref4.apply(this, arguments);
    };
  }());

  test('tarball contains schemas and metadata', function () {
    var _ref5 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee5(done) {
      var doc, shoulds;
      return _regenerator2.default.wrap(function _callee5$(_context5) {
        while (1) {
          switch (_context5.prev = _context5.next) {
            case 0:
              _context5.next = 2;
              return documenter({
                schemas: validate.schemas,
                tier: tier
              });

            case 2:
              doc = _context5.sent;
              shoulds = ['taskcluster-lib-docs/schema/foo.json', 'taskcluster-lib-docs/schema/bar.json'];

              assertInTarball(shoulds, doc.tgz, done);

            case 5:
            case 'end':
              return _context5.stop();
          }
        }
      }, _callee5, this);
    }));

    return function (_x2) {
      return _ref5.apply(this, arguments);
    };
  }());

  test('tarball contains references and metadata', function () {
    var _ref6 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee6(done) {
      var doc, shoulds;
      return _regenerator2.default.wrap(function _callee6$(_context6) {
        while (1) {
          switch (_context6.prev = _context6.next) {
            case 0:
              _context6.next = 2;
              return documenter({
                references: references,
                tier: tier
              });

            case 2:
              doc = _context6.sent;
              shoulds = ['taskcluster-lib-docs/references/api.json', 'taskcluster-lib-docs/references/events.json'];

              assertInTarball(shoulds, doc.tgz, done);

            case 5:
            case 'end':
              return _context6.stop();
          }
        }
      }, _callee6, this);
    }));

    return function (_x3) {
      return _ref6.apply(this, arguments);
    };
  }());

  test('tarball contains only metadata', function () {
    var _ref7 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee7(done) {
      var doc;
      return _regenerator2.default.wrap(function _callee7$(_context7) {
        while (1) {
          switch (_context7.prev = _context7.next) {
            case 0:
              _context7.next = 2;
              return documenter({
                tier: tier
              });

            case 2:
              doc = _context7.sent;

              assertInTarball([], doc.tgz, done);

            case 4:
            case 'end':
              return _context7.stop();
          }
        }
      }, _callee7, this);
    }));

    return function (_x4) {
      return _ref7.apply(this, arguments);
    };
  }());
});
//# sourceMappingURL=main_test.js.map
